kbench_mod: Fix build on sparc64.

get_tick() is not a good function name, namespace wise, so use
kbench_get_tick() instead.

Signed-off-by: David S. Miller <davem@davemloft.net>
diff --git a/kbench_mod.c b/kbench_mod.c
index 950c66d..476f9d4 100644
--- a/kbench_mod.c
+++ b/kbench_mod.c
@@ -15,7 +15,7 @@
  */
 
 #ifdef CONFIG_SPARC64
-static inline unsigned long long get_tick(void)
+static inline unsigned long long kbench_get_tick(void)
 {
 	unsigned long long t;
 
@@ -23,7 +23,7 @@
 	return t;
 }
 #elif defined(CONFIG_X86)
-static inline unsigned long long get_tick(void)
+static inline unsigned long long kbench_get_tick(void)
 {
 	unsigned long long t;
 
@@ -32,12 +32,12 @@
 	return t;
 }
 #elif defined(CONFIG_POWERPC)
-static inline unsigned long long get_tick(void)
+static inline unsigned long long kbench_get_tick(void)
 {
 	return get_cycles();
 }
 #else
 #error Unsupported architecture, please implement get_tick()
 #endif
 
 #undef IP_ROUTE_HAVE_PREALLOC
@@ -142,9 +142,9 @@
 
 	flow_init(&fl4);
 
-	t1 = get_tick();
+	t1 = kbench_get_tick();
 	rt = route_output(&init_net, &fl4);
-	t2 = get_tick();
+	t2 = kbench_get_tick();
 	if (!IS_ERR(rt))
 		ip_rt_put(rt);
 
@@ -202,9 +202,9 @@
 	}
 
 	local_bh_disable();
-	t1 = get_tick();
+	t1 = kbench_get_tick();
 	err = ip_route_input(skb, flow_dst_ip_addr, flow_src_ip_addr, flow_tos, dev);
-	t2 = get_tick();
+	t2 = kbench_get_tick();
 	local_bh_enable();
 
 	if (err) {
@@ -266,9 +266,9 @@
 
 	flow_init(&fl4);
 
-	t1 = get_tick();
+	t1 = kbench_get_tick();
 	rt = ip_route_output_flow_prealloc(&init_net, &fl4, NULL, &rt_stack.dst);
-	t2 = get_tick();
+	t2 = kbench_get_tick();
 	if (!IS_ERR(rt))
 		ip_rt_put(rt);
 
@@ -315,14 +315,14 @@
 	{
 		struct fib_table *table;
 
-		t1 = get_tick();
+		t1 = kbench_get_tick();
 		table = fib_get_table(&init_net, RT_TABLE_MAIN);
 		if (!table) {
 			pr_info("fib_lookup: No main table.\n");
 			return;
 		}
 		err = fib_table_lookup(table, &fl4, &res, FIB_LOOKUP_NOREF);
-		t2 = get_tick();
+		t2 = kbench_get_tick();
 	}
 	tdiff = t2 - t1;
 	pr_info("fib_lookup tdiff: %llu\n", tdiff);
@@ -407,9 +407,9 @@
 			return;
 		}
 	}
-	t1 = get_tick();
+	t1 = kbench_get_tick();
 	err = new_output_lookup(&fl, &rt);
-	t2 = get_tick();
+	t2 = kbench_get_tick();
 
 	if (err) {
 		pr_info("new_output_lookup: err=%d\n", err);
@@ -32,12 +32,12 @@
 }
 #else
-#error Unsupported architecture, please implement get_tick()
+#error Unsupported architecture, please implement kbench_get_tick()
 #endif
 